#!/usr/bin/env bash

RED="\e[31m"
GRN="\e[32m"
WHT="\e[37m"
CLR="\e[0m"

# Platform aliases
case $PLATFORM in
  ""|pc|qemu)
    PLATFORM=pc_qemu
  ;;
  iso)
    PLATFORM=pc_iso
  ;;

  docker)
    PLATFORM=docker_64
  ;;

  qemu_32)
    PLATFORM=pc_qemu_32
  ;;
  iso_32)
    PLATFORM=pc_iso_32
  ;;

  qemu_64)
    PLATFORM=pc_qemu_64
  ;;
  iso_64)
    PLATFORM=pc_iso_64
  ;;

  raspberry)
    PLATFORM=raspberry_qemu
  ;;
esac

# default CPU for each platform
if [[ -z "$CPU" ]]; then
  case $PLATFORM in
    *_32)
      CPU=i686
    ;;
    *_64)
      CPU=x86_64
    ;;

    raspberry_*)
      CPU=armv6j
#      CPU=armv6zk
    ;;

    *)
#      CPU=native  # https://gcc.gnu.org/onlinedocs/gcc-4.9.2/gcc/i386-and-x86-64-Options.html#i386-and-x86-64-Options
      CPU=`uname -m`
    ;;
  esac
fi

# [Hack] Can't be able to use x86_64 as generic x86 64 bits CPU
case $CPU in
  x86_64)
    CPU=nocona
  ;;
esac

# Normalice platforms
case $PLATFORM in
  docker_*)
    PLATFORM=docker
  ;;

  pc_qemu_*)
    PLATFORM=pc_qemu
  ;;
  pc_iso_*)
    PLATFORM=pc_iso
  ;;

#  raspberry_*)
#    PLATFORM=raspberry
#  ;;

  vagga_*)
    PLATFORM=vagga
  ;;
esac

# Set target and architecture for the selected CPU
case $CPU in
  armv6j)
#  armv6zk)
    ARCH="arm"
    BITS=32
    CPU_FAMILY=arm
    CPU_PORT=armhf
    FLOAT_ABI=hard
    FPU=vfp
    NODE_ARCH=arm
    TARGET=$CPU-nodeos-linux-musleabihf
#    TUNE=arm1136jf-s
#    TUNE=arm1176jzf-s
  ;;

  i[34567]86)
    ARCH="x86"
    BITS=32
    CPU_FAMILY=i386
    CPU_PORT=$CPU_FAMILY
    NODE_ARCH=ia32
    TARGET=$CPU-nodeos-linux-musl
  ;;

  x86_64|nocona)
    ARCH="x86"
    BITS=64
    CPU_FAMILY=x86_64
    CPU_PORT=$CPU_FAMILY
    NODE_ARCH=x64
#    TARGET=$CPU-nodeos-linux-musl
    TARGET=x86_64-nodeos-linux-musl
  ;;

  *)
    echo "Unknown CPU '$CPU'"
    exit 1
  ;;
esac


# Set host triplet and number of concurrent jobs
HOST=$(echo ${MACHTYPE} | sed "s/-[^-]*/-cross/")

if [[ -z $JOBS ]]; then
  JOBS=$((`getconf _NPROCESSORS_ONLN` + 1))
fi


# Auxiliar variables
OBJECTS=`pwd`/build/$CPU

MAKE1="make ${SILENT:=--silent LIBTOOLFLAGS=--silent V=}"
MAKE="$MAKE1 --jobs=$JOBS"


function rmStep(){
  rm -rf "$@"
  rmdir -p --ignore-fail-on-non-empty `dirname "$@"`
}

# Clean object dir and return the input error
function err(){
  echo -e "${RED}Error compiling '${OBJ_DIR}'${CLR}"
  rmStep $OBJ_DIR
  exit $1
}
